Class: Newsmlg2::Action
- Inherits:
-
Types::QualRelPropType
- Object
- Types::QualRelPropType
- Newsmlg2::Action
- Defined in:
- lib/newsmlg2/items/any_item.rb
Overview
An action which is executed at this hop in the hop history.
An action which is executed at this hop in the hop history.