Class: Newsmlg2::CatalogRef
- Inherits:
-
NarModel
- Object
- NarModel
- Newsmlg2::CatalogRef
- Defined in:
- lib/newsmlg2/catalog_ref.rb
Overview
A reference to a remote catalog: a hyperlink to a set of scheme alias declarations.
A reference to a remote catalog: a hyperlink to a set of scheme alias declarations.