Class: Newsmlg2::DerivedFrom

Inherits:
Types::Flex1PropType
  • Object
show all
Defined in:
lib/newsmlg2/items/any_item.rb

Overview

Refers to the ids of elements whose values have been derived from the concept represented by this property.