Class: Newsmlg2::DerivedFromValue

Inherits:
NarModel
  • Object
show all
Includes:
Base::CommonPowerAttributes
Defined in:
lib/newsmlg2/items/any_item.rb

Overview

Represents the non-Concept value that was used for deriving the value of one or more properties in this NewsML-G2 item.

Method Summary

Methods included from Base::CommonPowerAttributes

included