Class: Newsmlg2::GroupRef
- Inherits:
-
NarModel
- Object
- NarModel
- Newsmlg2::GroupRef
- Includes:
- Base::CommonPowerAttributes
- Defined in:
- lib/newsmlg2/items/package_item.rb
Overview
A reference to a group local to the package.
A reference to a group local to the package.