Class: Newsmlg2::ItemMeta
- Inherits:
-
NarModel
- Object
- NarModel
- Newsmlg2::ItemMeta
- Defined in:
- lib/newsmlg2/items/any_item.rb
Overview
A set of properties directly associated with the Item.
A set of properties directly associated with the Item.