Class: Newsmlg2::KnowledgeItem

Inherits:
AnyItem
  • Object
show all
Defined in:
lib/newsmlg2/items/knowledge_item.rb

Overview

An Item used for collating a set of concept definitions to form the physical representation of a controlled vocabulary.

Method Summary

Methods inherited from AnyItem

#validate!

Methods included from Base::I18NAttributes

included