Class: Newsmlg2::Planning
- Inherits:
-
NarModel
- Object
- NarModel
- Newsmlg2::Planning
- Defined in:
- lib/newsmlg2/items/planning_item.rb
Overview
Details about the planned news coverage by a specific kind of G2 item.
Details about the planned news coverage by a specific kind of G2 item.