Class: Newsmlg2::RemoteContent

Inherits:
NarModel
  • Object
show all
Includes:
Base::NewsContentAttributes, Base::NewsContentCharacteristics, Base::TargetResourceAttributes, Base::TimeValidityAttributes
Defined in:
lib/newsmlg2/items/news_item.rb

Overview

A rendition of the content using a reference to a resource representing the content data at a remote location.

Method Summary

Methods included from Base::NewsContentCharacteristics

included

Methods included from Base::TimeValidityAttributes

included

Methods included from Base::TargetResourceAttributes

included

Methods included from Base::NewsContentAttributes

included