Class: Newsmlg2::SameAsScheme

Inherits:
NarModel
  • Object
show all
Includes:
Base::CommonPowerAttributes
Defined in:
lib/newsmlg2/same_as_scheme.rb

Overview

A URI identifying another scheme whose concepts use the same codes and are semantically equivalent to the concepts of this scheme.

Method Summary

Methods included from Base::CommonPowerAttributes

included