Class: Newsmlg2::KnowledgeItem
- Defined in:
- lib/newsmlg2/items/knowledge_item.rb
Overview
An Item used for collating a set of concept definitions to form the physical representation of a controlled vocabulary.
An Item used for collating a set of concept definitions to form the physical representation of a controlled vocabulary.