Class: Newsmlg2::RemoteContent
- Inherits:
-
NarModel
- Object
- NarModel
- Newsmlg2::RemoteContent
- Includes:
- Base::NewsContentAttributes, Base::NewsContentCharacteristics, Base::TargetResourceAttributes, Base::TimeValidityAttributes
- Defined in:
- lib/newsmlg2/items/news_item.rb
Overview
A rendition of the content using a reference to a resource representing the content data at a remote location.