Class: Newsmlg2::Types::Affiliation
- Inherits:
-
NarModel
- Object
- Lutaml::Model::Serializable
- NarModel
- Newsmlg2::Types::Affiliation
- Includes:
- Base::CommonPowerAttributes, Base::ConceptDefinitionGroup, Base::ConceptRelationshipsGroup, Base::I18NAttributes, Base::QualifyingAttributes, Base::TimeValidityAttributes
- Defined in:
- lib/newsmlg2/types/party_details.rb
Overview
An affiliation of a person or an organisation with an organisation. Composed (rather than subclassing a flex organisation type) so the flex prop types and the detail types never reference each other's class bodies. python-newsmlg2 models this as two identical classes (PersonAffiliationType, OrganisationAffiliationType).
Method Summary
Methods included from Base::ConceptRelationshipsGroup
Methods included from Base::ConceptDefinitionGroup
Methods included from Base::TimeValidityAttributes
Methods included from Base::I18NAttributes
Methods included from Base::QualifyingAttributes
Methods included from Base::CommonPowerAttributes
Methods inherited from NarModel
lutaml_default_register, xml_attributes, xml_content, xml_element, xml_lang_attribute, xml_root_name