Class: Newsmlg2::Types::RelatedConceptType
- Inherits:
-
FlexPropType
- Object
- Lutaml::Model::Serializable
- NarModel
- FlexPropType
- Newsmlg2::Types::RelatedConceptType
- Includes:
- Base::TimeValidityAttributes
- Defined in:
- lib/newsmlg2/types/related_concept.rb,
lib/newsmlg2/types/related_concept.rb
Overview
The type for an identifier of a related concept.
NOTE: the :related child is declared at the bottom of this file (after Related exists) because Related's inheritance chain passes through RelatedConceptType — an eager reference here would be a circular autoload.
Direct Known Subclasses
Broader, FacetConcept, FlexRelatedConceptType, MainConcept, Narrower
Method Summary
Methods included from Base::TimeValidityAttributes
Methods included from Base::I18NAttributes
Methods included from Base::FlexAttributes
Methods included from Base::CommonPowerAttributes
Methods inherited from NarModel
lutaml_default_register, xml_attributes, xml_content, xml_element, xml_lang_attribute, xml_root_name